#include "ofApp.h"

//--------------------------------------------------------------
void ofApp::setup(){
    ofBackground(100);
    section=1;
    ofSetFrameRate(60);
    
    //text
    font.loadFont("Futura ICG.ttf", 80);
    textBox=font.getStringBoundingBox("07:32", 0, 0);
    
    //Swipping setting
    ofxAccelerometer.setup();               //accesses accelerometer data
    ofxiPhoneAlerts.addListener(this);      //allows elerts to appear while app is running
    ofRegisterTouchEvents(this);            //method that passes touch events
    
    swipping.setup();
    ofAddListener(swipping.swipeRecognized, this, &ofApp::onSwipe);
    totalSwipes = 0;
    direction = 0;
    
    //iamges
    img0.loadImage("img0.jpg");
    img1.loadImage("img1.png");
    img2.loadImage("img2.png");
    img3.loadImage("img3.png");
    img4.loadImage("img4.png");
    
    ins1.loadImage("firstPage.png");
    ins2.loadImage("secondPage.png");
    ins3.loadImage("thirdPage.png");
    
    //button
    btnWidth=330;
    btnHeight=330;
    
    //video and sound
    myVideo.loadMovie("firstPage.mp4");
    mySound.loadSound("soundExample.wav");
    mySound.setLoop(OF_LOOP_NORMAL);
    myVideo.setLoopState(OF_LOOP_NORMAL);
    
    alphaFadeIn=0;
    
    //starting video in section 1 immediately
    if (section<=3) {
        mySound.play();
    }
    
}

//--------------------------------------------------------------
void ofApp::update(){
    myVideo.update();
    
}

//--------------------------------------------------------------
void ofApp::draw(){
    switch (section) {
        case 1:
            ins1.draw(0, 0,ofGetWidth(),ofGetHeight());
            break;
            
        case 2:
            ins2.draw(0, 0, ofGetWidth(),ofGetHeight());
            break;
            
        case 3:
            ins3.draw(0, 0, ofGetWidth(),ofGetHeight());
            break;
            
        case 4:
            ofPushMatrix();
            
            ofBackground(255, 255, 255);
            ofTranslate(ofGetWidth()/2, ofGetHeight()/2);
            img1.draw(-img1.width, -img1.height);
            img2.draw(0, -img1.height);
            img3.draw(-img3.width,0);
            img4.draw(0, 0);
            
            btn1.set(ofGetWidth()/2-img1.width, ofGetHeight()/2-img1.height,btnWidth, btnHeight);
            btn2.set(ofGetWidth()/2+img1.width, ofGetHeight()/2-img1.height,btnWidth, btnHeight);
            btn3.set(ofGetWidth()/2-img1.width, ofGetHeight()/2+img1.height,btnWidth, btnHeight);
            btn4.set(ofGetWidth()/2+img1.width, ofGetHeight()/2+img1.height,btnWidth, btnHeight);
            
            ofPopMatrix();
            break;
            
        case 5:
           
            ofEnableAlphaBlending(); // got to have this somewhere to use opacity
            ofBackground(0);
            
            if (ofGetFrameNum()%5) {
                alphaFadeIn++;
            }
            ofSetColor(255, alphaFadeIn);
            myVideo.draw(0,0,ofGetWidth(),ofGetHeight());
            
            ofPushMatrix();
            ofTranslate(ofGetWidth()/2, ofGetHeight()/2);
            ofSetColor(255, 200);
            font.drawString("07:32", -textBox.width/2, +textBox.height/2);
            ofPopMatrix();
            
            break;
            
        case 6:
            img0.draw(0,0,ofGetWidth(),ofGetHeight());
            break;

        default:
            break;
       
    }
    
}

//--------------------------------------------------------------
void ofApp::onSwipe(ofSwipeGestureRecognizerArgs & args){
    
    cout << " Swipe Event! Yes! " << endl;
    
    direction = args.direction;
    totalSwipes = args.totalSwipes;
    
    if (direction==2) {
        section=direction+(section-1);
    }
    if (direction==1) {
        section=section-direction;
    }
    if (section==5){
        myVideo.setFrame(0);
        myVideo.play();
        
        alphaFadeIn=0;
    
    }else{
        myVideo.setPaused(true);
    }
    if (section>3) {
        mySound.setPaused(true);
    }
}


//--------------------------------------------------------------
void ofApp::exit(){
    
}

//--------------------------------------------------------------
void ofApp::touchDown(ofTouchEventArgs & touch){
    
}
//--------------------------------------------------------------
void ofApp::touchMoved(ofTouchEventArgs & touch){
    
    if (btn1.inside(touch.x, touch.y)) {
        section=5;
    }
    if (btn2.inside(touch.x, touch.y)) {
        section=5;
    }
    if (btn3.inside(touch.x, touch.y)) {
        section=5;
    }
    if (btn4.inside(touch.x, touch.y)) {
        section=5;
    }
    if (section==5){
        myVideo.setFrame(0);
        myVideo.play();
        
        alphaFadeIn=0;
        
    }else{
        myVideo.setPaused(true);
    }
}

//--------------------------------------------------------------
void ofApp::touchUp(ofTouchEventArgs & touch){
    
}

//--------------------------------------------------------------
void ofApp::touchDoubleTap(ofTouchEventArgs & touch){
}

//--------------------------------------------------------------
void ofApp::touchCancelled(ofTouchEventArgs & touch){
    
}

//--------------------------------------------------------------
void ofApp::lostFocus(){
    
}

//--------------------------------------------------------------
void ofApp::gotFocus(){
    
}

//--------------------------------------------------------------
void ofApp::gotMemoryWarning(){
    
}

//--------------------------------------------------------------
void ofApp::deviceOrientationChanged(int newOrientation){
    
}
